@@ -13,10 +13,22 @@ use Perinci::Sub::Util qw(gen_modified_sub);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-26'; # DATE
 our $DIST = 'File-Util-Sort'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our %SPEC;
 
+our @EXPORT_OK = qw(
+                       sort_files
+                       foremost
+                       hindmost
+                       largest
+                       smallest
+                       newest
+                       oldest
+                       longest_name
+                       shortest_name
+               );
+
 my @file_types = qw(file dir);
 
 my @file_fields = qw(name size mtime ctime);
@@ -683,7 +695,7 @@ File::Util::Sort - Routines related to sorting files in one or more directories
 
 =head1 VERSION
 
-This document describes version 0.009 of File::Util::Sort (from Perl distribution File-Util-Sort), released on 2023-11-26.
+This document describes version 0.010 of File::Util::Sort (from Perl distribution File-Util-Sort), released on 2023-11-26.
 
 =head1 DESCRIPTION
 
@@ -711,7 +723,7 @@ Some examples:
  # return foremost file in current directory
  % foremost -f
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -801,7 +813,7 @@ Some examples:
  # return hindmost file in current directory
  % hindmost -f
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -887,7 +899,7 @@ Some examples:
  # same size they will all be returned
  % largest -N1 -f /some/dir
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -977,7 +989,7 @@ Some examples:
  # files with the same length, they will all be returned.
  % longest-name -N1 -f /some/dir
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -1083,7 +1095,7 @@ Some examples:
  # same newest mtime) they will all be returned
  % newest -N1 -f /some/dir
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -1175,7 +1187,7 @@ Some examples:
  # same oldest mtime) they will all be returned
  % oldest -N1 -f /some/dir
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -1265,7 +1277,7 @@ Some examples:
  # files with the same length, they will all be returned.
  % shortest-name -N1 -f /some/dir
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -1347,7 +1359,7 @@ Some examples:
  # same size they will all be returned
  % smallest -N1 -f /some/dir
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
@@ -1420,7 +1432,7 @@ Usage:
 
 Sort files in one or more directories and display the result in a flexible way.
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
